function y=polyLagrange(X,Y,x)
% LAGRANGE computes the interpolation polynomial in the Lagrange form
% -- y=Lagrange(X,Y,x)
%      returns the interpolate values y as the Lagrange form of the 
%      interpolating polynomial using the points (X(i),Y(j)) so that
%         y(j)=P_n(x(j))
%
  m=length(x);
  y=zeros(size(x));
  for i=1:m 
    y(i)=LagrangeSca(X,Y,x(i));
  end
end

function y=LagrangeSca(X,Y,x) % x is a scalar, so y=P_n(x) is a scalar
  n=length(X);
  y=0;
  for i=1:n 
    L=1;
    for j=[1:i-1,i+1:n]  
      L=L*(x-X(j))/(X(i)-X(j));
    end
    y=y+Y(i)*L;
  end
end

